# aiodown

![License](https://img.shields.io/github/license/AmanoTeam/aiodown)
![Codacy](https://app.codacy.com/project/badge/Grade/9333a571fcf442c78ac2fc9802d3ded3)
![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)
![Contributors](https://img.shields.io/github/contributors/AmanoTeam/aiodown.svg)

> An `asyncio-based` file downloader made in `Python 3` using [httpx](//github.com/encode/httpx).

## Requirements

- Python 3.8 or higher.
- httpx 0.14 or higher.
- async-files 0.4 or higher.

## Installation

**NOTE:** If `python3` is "not a recognized command" try using `python` instead.

For the latest stable version:<br>
```
python3 -m pip install aiodown
```

For the latest development version:<br>
```
python3 -m pip install git+https://github.com/AmanoTeam/aiodown
```

## What's left to do?

- Write the API Documentation.
- Show some examples.

## License

MIT © 2021 [AmanoTeam](//github.com/AmanoTeam)